Class: Aws::Interconnect::Types::AcceptConnectionProposalRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:activation_key]

Instance Attribute Summary collapse

Instance Attribute Details

#activation_keyString

An Activation Key that was generated on a supported partner’s portal. This key captures the desired parameters from the initial creation request.

The details of this request can be described using with DescribeConnectionProposal.

Returns:

  • (String)


43
44
45
46
47
48
49
50
51
# File 'lib/aws-sdk-interconnect/types.rb', line 43

class AcceptConnectionProposalRequest < Struct.new(
  :attach_point,
  :activation_key,
  :description,
  :tags,
  :client_token)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#attach_pointTypes::AttachPoint

The Attach Point to which the connection should be associated.

Returns:



43
44
45
46
47
48
49
50
51
# File 'lib/aws-sdk-interconnect/types.rb', line 43

class AcceptConnectionProposalRequest < Struct.new(
  :attach_point,
  :activation_key,
  :description,
  :tags,
  :client_token)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#client_tokenString

Idempotency token used for the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


43
44
45
46
47
48
49
50
51
# File 'lib/aws-sdk-interconnect/types.rb', line 43

class AcceptConnectionProposalRequest < Struct.new(
  :attach_point,
  :activation_key,
  :description,
  :tags,
  :client_token)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#descriptionString

A description to distinguish this Connection.

Returns:

  • (String)


43
44
45
46
47
48
49
50
51
# File 'lib/aws-sdk-interconnect/types.rb', line 43

class AcceptConnectionProposalRequest < Struct.new(
  :attach_point,
  :activation_key,
  :description,
  :tags,
  :client_token)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#tagsHash<String,String>

The tags to associate with the resulting Connection.

Returns:

  • (Hash<String,String>)


43
44
45
46
47
48
49
50
51
# File 'lib/aws-sdk-interconnect/types.rb', line 43

class AcceptConnectionProposalRequest < Struct.new(
  :attach_point,
  :activation_key,
  :description,
  :tags,
  :client_token)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end