Class: Aws::Interconnect::Types::AccessDeniedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

The calling principal is not allowed to access the specified resource, or the resource does not exist.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


73
74
75
76
77
# File 'lib/aws-sdk-interconnect/types.rb', line 73

class AccessDeniedException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end