Class: Aws::Interconnect::Types::AttachPoint

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Note:

AttachPoint is a union - when making an API calls you must set exactly one of the members.

Note:

AttachPoint is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AttachPoint corresponding to the set member.

Identifies an attach point to use with a Connection.

Direct Known Subclasses

Arn, DirectConnectGateway, Unknown

Defined Under Namespace

Classes: Arn, DirectConnectGateway, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Identifies an attach point by full ARN.

Returns:

  • (String)


96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/aws-sdk-interconnect/types.rb', line 96

class AttachPoint < Struct.new(
  :direct_connect_gateway,
  :arn,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DirectConnectGateway < AttachPoint; end
  class Arn < AttachPoint; end
  class Unknown < AttachPoint; end
end

#direct_connect_gatewayString

Identifies an DirectConnect Gateway attach point by DirectConnectGatewayID.

Returns:

  • (String)


96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/aws-sdk-interconnect/types.rb', line 96

class AttachPoint < Struct.new(
  :direct_connect_gateway,
  :arn,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class DirectConnectGateway < AttachPoint; end
  class Arn < AttachPoint; end
  class Unknown < AttachPoint; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



96
97
98
# File 'lib/aws-sdk-interconnect/types.rb', line 96

def unknown
  @unknown
end