Class: Aws::Interconnect::Types::AttachPointDescriptor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Describes a possible Attach Point for a Connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

The identifier for the specific type of the AttachPoint.

Returns:

  • (String)


132
133
134
135
136
137
138
# File 'lib/aws-sdk-interconnect/types.rb', line 132

class AttachPointDescriptor < Struct.new(
  :type,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The descriptive name of the identifier attach point.

Returns:

  • (String)


132
133
134
135
136
137
138
# File 'lib/aws-sdk-interconnect/types.rb', line 132

class AttachPointDescriptor < Struct.new(
  :type,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of this AttachPoint, which will dictate the syntax of the identifier.

Current types include:

  • ARN

  • DirectConnect Gateway

Returns:

  • (String)


132
133
134
135
136
137
138
# File 'lib/aws-sdk-interconnect/types.rb', line 132

class AttachPointDescriptor < Struct.new(
  :type,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end