Class: Aws::Interconnect::Types::Bandwidths

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Contains the details about the available and supported bandwidths.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availableArray<String>

The list of currently available bandwidths.

Returns:

  • (Array<String>)


152
153
154
155
156
157
# File 'lib/aws-sdk-interconnect/types.rb', line 152

class Bandwidths < Struct.new(
  :available,
  :supported)
  SENSITIVE = []
  include Aws::Structure
end

#supportedArray<String>

The list of all bandwidths that this environment plans to support

Returns:

  • (Array<String>)


152
153
154
155
156
157
# File 'lib/aws-sdk-interconnect/types.rb', line 152

class Bandwidths < Struct.new(
  :available,
  :supported)
  SENSITIVE = []
  include Aws::Structure
end