Class: Aws::Interconnect::Types::Connection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

The object describing the provided connectivity from the AWS region to the partner location.

Constant Summary collapse

SENSITIVE =
[:activation_key]

Instance Attribute Summary collapse

Instance Attribute Details

#activation_keyString

The Activation Key associated to this connection.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#arnString

An ARN of a Connection object.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#attach_pointTypes::AttachPoint

The Attach Point to which the connection should be associated.“

Returns:



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#bandwidthString

The specific selected bandwidth of this connection.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#billing_tierInteger

The billing tier this connection is currently assigned.

Returns:

  • (Integer)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#descriptionString

A descriptive name for the connection.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#environment_idString

The specific Environment this connection is placed upon.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#idString

The short identifier of the connection object.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#locationString

The provider specific location on the remote side of this Connection

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#owner_accountString

The account that owns this Connection

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#providerTypes::Provider

The provider on the remote side of this Connection.

Returns:



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#shared_idString

An identifier used by both AWS and the remote partner to identify the specific connection.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#stateString

  • ‘requested`: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal.

  • ‘pending`: The connection has been accepted and is being provisioned between AWS and the Partner.

  • ‘available`: The connection has been fully provisioned between AWS and the Partner.

  • ‘deleting`: The connection is being deleted.

  • ‘deleted`: The connection has been deleted.

  • ‘failed`: The connection has failed to be created.

  • ‘updating`: The connection is being updated.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#tagsHash<String,String>

The tags on the Connection

Returns:

  • (Hash<String,String>)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end

#typeString

The specific product type of this Connection.

Returns:

  • (String)


241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/aws-sdk-interconnect/types.rb', line 241

class Connection < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier,
  :owner_account,
  :activation_key,
  :tags)
  SENSITIVE = [:activation_key]
  include Aws::Structure
end