Class: Aws::Interconnect::Types::ConnectionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Summarized view of a Connection object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the Connection

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#attach_pointTypes::AttachPoint

The Attach Point to which the connection should be associated.

Returns:



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#bandwidthString

The bandwidth of the Connection

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#billing_tierInteger

The billing tier this connection is currently assigned.

Returns:

  • (Integer)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A descriptive name of the Connection

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

The Environment that this Connection is created on.

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the requested Connection

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The provider specific location at the remote end of this Connection

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#providerTypes::Provider

The provider on the remote end of this Connection

Returns:



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#shared_idString

An identifier used by both AWS and the remote partner to identify the specific connection.

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

  • ‘requested`: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal.

  • ‘pending`: The connection has been accepted and is being provisioned between AWS and the Partner.

  • ‘available`: The connection has been fully provisioned between AWS and the Partner.

  • ‘deleting`: The connection is being deleted.

  • ‘deleted`: The connection has been deleted.

  • ‘failed`: The connection has failed to be created.

  • ‘updating`: The connection is being updated.

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The product variant supplied by this resource.

Returns:

  • (String)


330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/aws-sdk-interconnect/types.rb', line 330

class ConnectionSummary < Struct.new(
  :id,
  :arn,
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :provider,
  :location,
  :type,
  :state,
  :shared_id,
  :billing_tier)
  SENSITIVE = []
  include Aws::Structure
end