Class: Aws::Interconnect::Types::CreateConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_pointTypes::AttachPoint

The Attach Point to which the connection should be associated.“

Returns:



385
386
387
388
389
390
391
392
393
394
395
# File 'lib/aws-sdk-interconnect/types.rb', line 385

class CreateConnectionRequest < Struct.new(
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :remote_account,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#bandwidthString

The desired bandwidth of the requested Connection

Returns:

  • (String)


385
386
387
388
389
390
391
392
393
394
395
# File 'lib/aws-sdk-interconnect/types.rb', line 385

class CreateConnectionRequest < Struct.new(
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :remote_account,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Idempotency token used for the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


385
386
387
388
389
390
391
392
393
394
395
# File 'lib/aws-sdk-interconnect/types.rb', line 385

class CreateConnectionRequest < Struct.new(
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :remote_account,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description to distinguish this Connection.

Returns:

  • (String)


385
386
387
388
389
390
391
392
393
394
395
# File 'lib/aws-sdk-interconnect/types.rb', line 385

class CreateConnectionRequest < Struct.new(
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :remote_account,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

The identifier of the Environment across which this Connection should be created.

The available Environment objects can be determined using ListEnvironments.

Returns:

  • (String)


385
386
387
388
389
390
391
392
393
394
395
# File 'lib/aws-sdk-interconnect/types.rb', line 385

class CreateConnectionRequest < Struct.new(
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :remote_account,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#remote_accountTypes::RemoteAccountIdentifier

Account and/or principal identifying information that can be verified by the partner of this specific Environment.



385
386
387
388
389
390
391
392
393
394
395
# File 'lib/aws-sdk-interconnect/types.rb', line 385

class CreateConnectionRequest < Struct.new(
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :remote_account,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tag to associate with the resulting Connection.

Returns:

  • (Hash<String,String>)


385
386
387
388
389
390
391
392
393
394
395
# File 'lib/aws-sdk-interconnect/types.rb', line 385

class CreateConnectionRequest < Struct.new(
  :description,
  :bandwidth,
  :attach_point,
  :environment_id,
  :remote_account,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end