Class: Aws::Interconnect::Types::DeleteConnectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::DeleteConnectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection ⇒ Types::Connection
The Connection object that has been marked for deletion.
Instance Attribute Details
#connection ⇒ Types::Connection
The Connection object that has been marked for deletion.
435 436 437 438 439 |
# File 'lib/aws-sdk-interconnect/types.rb', line 435 class DeleteConnectionResponse < Struct.new( :connection) SENSITIVE = [] include Aws::Structure end |