Class: Aws::Interconnect::Types::DescribeConnectionProposalRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::DescribeConnectionProposalRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:activation_key]
Instance Attribute Summary collapse
-
#activation_key ⇒ String
An Activation Key that was generated on a supported partner’s portal.
Instance Attribute Details
#activation_key ⇒ String
An Activation Key that was generated on a supported partner’s portal. This key captures the desired parameters from the initial creation request.
449 450 451 452 453 |
# File 'lib/aws-sdk-interconnect/types.rb', line 449 class DescribeConnectionProposalRequest < Struct.new( :activation_key) SENSITIVE = [:activation_key] include Aws::Structure end |