Class: Aws::Interconnect::Types::DescribeConnectionProposalResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidthString

The bandwidth of the proposed Connection.

Returns:

  • (String)


475
476
477
478
479
480
481
482
# File 'lib/aws-sdk-interconnect/types.rb', line 475

class DescribeConnectionProposalResponse < Struct.new(
  :bandwidth,
  :environment_id,
  :provider,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

The identifier of the Environment upon which the Connection would be placed if this proposal were accepted.

Returns:

  • (String)


475
476
477
478
479
480
481
482
# File 'lib/aws-sdk-interconnect/types.rb', line 475

class DescribeConnectionProposalResponse < Struct.new(
  :bandwidth,
  :environment_id,
  :provider,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The partner specific location distinguisher of the specific Environment of the proposal.

Returns:

  • (String)


475
476
477
478
479
480
481
482
# File 'lib/aws-sdk-interconnect/types.rb', line 475

class DescribeConnectionProposalResponse < Struct.new(
  :bandwidth,
  :environment_id,
  :provider,
  :location)
  SENSITIVE = []
  include Aws::Structure
end

#providerTypes::Provider

The partner provider of the specific Environment of the proposal.

Returns:



475
476
477
478
479
480
481
482
# File 'lib/aws-sdk-interconnect/types.rb', line 475

class DescribeConnectionProposalResponse < Struct.new(
  :bandwidth,
  :environment_id,
  :provider,
  :location)
  SENSITIVE = []
  include Aws::Structure
end