Class: Aws::Interconnect::Types::ListConnectionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attach_pointTypes::AttachPoint

Filter results to only include Connection objects attached to the given AttachPoint.

Returns:



713
714
715
716
717
718
719
720
721
722
# File 'lib/aws-sdk-interconnect/types.rb', line 713

class ListConnectionsRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :environment_id,
  :provider,
  :attach_point)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

Filter the results to only include Connection objects on the given Environment.

Returns:

  • (String)


713
714
715
716
717
718
719
720
721
722
# File 'lib/aws-sdk-interconnect/types.rb', line 713

class ListConnectionsRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :environment_id,
  :provider,
  :attach_point)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The max number of list results in a single paginated response.

Returns:

  • (Integer)


713
714
715
716
717
718
719
720
721
722
# File 'lib/aws-sdk-interconnect/types.rb', line 713

class ListConnectionsRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :environment_id,
  :provider,
  :attach_point)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token from a previous paginated response indicating you wish to get the next page of results.

Returns:

  • (String)


713
714
715
716
717
718
719
720
721
722
# File 'lib/aws-sdk-interconnect/types.rb', line 713

class ListConnectionsRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :environment_id,
  :provider,
  :attach_point)
  SENSITIVE = []
  include Aws::Structure
end

#providerTypes::Provider

Filter the results to only include Connection objects to the given Provider.

Returns:



713
714
715
716
717
718
719
720
721
722
# File 'lib/aws-sdk-interconnect/types.rb', line 713

class ListConnectionsRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :environment_id,
  :provider,
  :attach_point)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Filter the results to only include Connection objects in the given Connection$state.

Returns:

  • (String)


713
714
715
716
717
718
719
720
721
722
# File 'lib/aws-sdk-interconnect/types.rb', line 713

class ListConnectionsRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :environment_id,
  :provider,
  :attach_point)
  SENSITIVE = []
  include Aws::Structure
end