Class: Aws::Interconnect::Types::ListConnectionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::ListConnectionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connections ⇒ Array<Types::ConnectionSummary>
The resulting list of Connection objects.
-
#next_token ⇒ String
A pagination token for use in subsequent calls to fetch the next page of results.
Instance Attribute Details
#connections ⇒ Array<Types::ConnectionSummary>
The resulting list of Connection objects.
735 736 737 738 739 740 |
# File 'lib/aws-sdk-interconnect/types.rb', line 735 class ListConnectionsResponse < Struct.new( :connections, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token for use in subsequent calls to fetch the next page of results.
735 736 737 738 739 740 |
# File 'lib/aws-sdk-interconnect/types.rb', line 735 class ListConnectionsResponse < Struct.new( :connections, :next_token) SENSITIVE = [] include Aws::Structure end |