Class: Aws::Interconnect::Types::RemoteAccountIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Note:

RemoteAccountIdentifier is a union - when making an API calls you must set exactly one of the members.

The types of identifiers that may be needed for remote account specification.

Direct Known Subclasses

Identifier, Unknown

Defined Under Namespace

Classes: Identifier, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#identifierString

A generic bit of identifying information. Can be used in place of any of the more specific types.

Returns:

  • (String)


857
858
859
860
861
862
863
864
865
866
# File 'lib/aws-sdk-interconnect/types.rb', line 857

class RemoteAccountIdentifier < Struct.new(
  :identifier,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Identifier < RemoteAccountIdentifier; end
  class Unknown < RemoteAccountIdentifier; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



857
858
859
# File 'lib/aws-sdk-interconnect/types.rb', line 857

def unknown
  @unknown
end