Class: Aws::Interconnect::Types::UpdateConnectionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-interconnect/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bandwidthString

Request a new bandwidth size on the given Connection.

Note that changes to the size may be subject to additional policy, and does require the remote partner provider to acknowledge and permit this new bandwidth size.

Returns:

  • (String)


976
977
978
979
980
981
982
983
# File 'lib/aws-sdk-interconnect/types.rb', line 976

class UpdateConnectionRequest < Struct.new(
  :identifier,
  :description,
  :bandwidth,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Idempotency token used for the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


976
977
978
979
980
981
982
983
# File 'lib/aws-sdk-interconnect/types.rb', line 976

class UpdateConnectionRequest < Struct.new(
  :identifier,
  :description,
  :bandwidth,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An updated description to apply to the Connection

Returns:

  • (String)


976
977
978
979
980
981
982
983
# File 'lib/aws-sdk-interconnect/types.rb', line 976

class UpdateConnectionRequest < Struct.new(
  :identifier,
  :description,
  :bandwidth,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the Connection that should be updated.

Returns:

  • (String)


976
977
978
979
980
981
982
983
# File 'lib/aws-sdk-interconnect/types.rb', line 976

class UpdateConnectionRequest < Struct.new(
  :identifier,
  :description,
  :bandwidth,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end