Class: Aws::Interconnect::Waiters::ConnectionAvailable
- Inherits:
-
Object
- Object
- Aws::Interconnect::Waiters::ConnectionAvailable
- Defined in:
- lib/aws-sdk-interconnect/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ConnectionAvailable
constructor
A new instance of ConnectionAvailable.
-
#wait(params = {}) ⇒ Types::GetConnectionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ConnectionAvailable
Returns a new instance of ConnectionAvailable.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-interconnect/waiters.rb', line 85 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_connection, acceptors: [ { "matcher" => "path", "argument" => "connection.state", "state" => "success", "expected" => "available" }, { "matcher" => "path", "argument" => "connection.state", "state" => "failure", "expected" => "deleted" }, { "matcher" => "path", "argument" => "connection.state", "state" => "failure", "expected" => "down" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
123 124 125 |
# File 'lib/aws-sdk-interconnect/waiters.rb', line 123 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetConnectionResponse
Returns a response object which responds to the following methods:
-
#connection => Types::Connection
118 119 120 |
# File 'lib/aws-sdk-interconnect/waiters.rb', line 118 def wait(params = {}) @waiter.wait(client: @client, params: params) end |