Class: Aws::Interconnect::Waiters::ConnectionDeleted
- Inherits:
-
Object
- Object
- Aws::Interconnect::Waiters::ConnectionDeleted
- Defined in:
- lib/aws-sdk-interconnect/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ConnectionDeleted
constructor
A new instance of ConnectionDeleted.
-
#wait(params = {}) ⇒ Types::GetConnectionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ConnectionDeleted
Returns a new instance of ConnectionDeleted.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/aws-sdk-interconnect/waiters.rb', line 135 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_connection, acceptors: [{ "matcher" => "path", "argument" => "connection.state", "state" => "success", "expected" => "deleted" }] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
159 160 161 |
# File 'lib/aws-sdk-interconnect/waiters.rb', line 159 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetConnectionResponse
Returns a response object which responds to the following methods:
-
#connection => Types::Connection
154 155 156 |
# File 'lib/aws-sdk-interconnect/waiters.rb', line 154 def wait(params = {}) @waiter.wait(client: @client, params: params) end |