Class: Aws::Interconnect::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-interconnect/client.rb

Overview

An API client for Interconnect. To construct a client, you need to configure a ‘:region` and `:credentials`.

client = Aws::Interconnect::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be any class that includes and implements ‘Aws::CredentialProvider`, or instance of any one of the following classes:

    • ‘Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • ‘Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • ‘Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • ‘Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • ‘Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • ‘Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • ‘Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • ‘Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • ‘Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When ‘:credentials` are not configured directly, the following locations will be searched for credentials:

    • Aws.config`

    • The ‘:access_key_id`, `:secret_access_key`, `:session_token`, and `:account_id` options.

    • ENV`, `ENV`, `ENV`, and `ENV`.

    • ‘~/.aws/credentials`

    • ‘~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of ‘Aws::InstanceProfileCredentials` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting `ENV` to `true`.

  • :region (required, String)

    The AWS region to connect to. The configured ‘:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to ‘true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in ‘adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: ‘sigv4`, `sigv4a`, `httpBearerAuth`, and `noAuth`. When set using `ENV` or in shared config as `auth_scheme_preference`, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When ‘true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When ‘true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in ‘standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When ‘true`, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to ‘true’ the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the ‘:endpoint` option directly. This is normally constructed from the `:region` option. Configuring `:endpoint` is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
    
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to ‘true`, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the ‘:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in ‘standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at ‘HOME/.aws/credentials`. When not specified, ’default’ is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • ‘when_supported` - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` and/or a `requestAlgorithmMember` is modeled.

    • ‘when_required` - When set, a checksum will only be calculated for request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` or where a `requestAlgorithmMember` is modeled and supplied.

  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • ‘when_supported` - (default) When set, checksum validation is performed on all response payloads of operations modeled with the `httpChecksum` trait where `responseAlgorithms` is modeled, except when no modeled checksum algorithms are supported.

    • ‘when_required` - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the `requestValidationModeMember` member is set to `ENABLED`.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the ‘legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the ‘legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the ‘legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • ‘legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • ‘standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • ‘adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default ‘:sigv4a_signing_region_set` is searched for in the following locations:

  • :simple_json (Boolean) — default: false

    Disables request parameter conversion, validation, and formatting. Also disables response data type conversions. The request parameters hash must be formatted exactly as the API expects.This option is useful when you want to ensure the highest level of performance by avoiding overhead of walking request parameters and response data structures.

  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses ‘NoOpTelemetryProvider` which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the

    ‘opentelemetry-sdk` gem and then, pass in an instance of a `Aws::Telemetry::OTelProvider` for telemetry provider.

  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be any class that includes and implements ‘Aws::TokenProvider`, or instance of any one of the following classes:

    • ‘Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • ‘Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When ‘:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to ‘true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to ‘true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When ‘true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::Interconnect::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to ‘#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::Interconnect::EndpointParameters`.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to ‘nil` which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like ‘proxy.com:123’.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When ‘true`, HTTP debug output will be sent to the `:logger`.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a ‘content-length`).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When ‘true`, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When ‘true`, SSL peer certificates are verified when establishing a connection.



480
481
482
# File 'lib/aws-sdk-interconnect/client.rb', line 480

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1798
1799
1800
# File 'lib/aws-sdk-interconnect/client.rb', line 1798

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1801
1802
1803
# File 'lib/aws-sdk-interconnect/client.rb', line 1801

def errors_module
  Errors
end

Instance Method Details

#accept_connection_proposal(params = {}) ⇒ Types::AcceptConnectionProposalResponse

Accepts a connection proposal which was generated at a supported partner’s portal.

The proposal contains the Environment and bandwidth that were chosen on the partner’s portal and cannot be modified.

Upon accepting the proposal a connection will be made between the AWS network as accessed via the selected Attach Point and the network previously selected network on the partner’s portal.

Examples:

Example: Accept Connection Proposal


resp = client.accept_connection_proposal({
  activation_key: "<Activation Key Data>", 
  attach_point: {
    direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
  }, 
})

resp.to_h outputs the following:
{
  connection: {
    type: "Multicloud", 
    activation_key: "<Activation Key Data>", 
    arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
    attach_point: {
      direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
    }, 
    bandwidth: "1Gbps", 
    description: "My MultiCloud Connection", 
    environment_id: "mce-aws-acme-1", 
    id: "mcc-abc12345", 
    location: "acme-east", 
    owner_account: "000000000000", 
    provider: {
      cloud_service_provider: "acme", 
    }, 
    shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
    state: "pending", 
  }, 
}

Request syntax with placeholder values


resp = client.accept_connection_proposal({
  attach_point: { # required
    direct_connect_gateway: "DirectConnectGatewayAttachPoint",
    arn: "AmazonResourceName",
  },
  activation_key: "ActivationKey", # required
  description: "ConnectionDescription",
  tags: {
    "TagKey" => "TagValue",
  },
  client_token: "String",
})

Response structure


resp.connection.id #=> String
resp.connection.arn #=> String
resp.connection.description #=> String
resp.connection.bandwidth #=> String
resp.connection.attach_point.direct_connect_gateway #=> String
resp.connection.attach_point.arn #=> String
resp.connection.environment_id #=> String
resp.connection.provider.cloud_service_provider #=> String
resp.connection.provider.last_mile_provider #=> String
resp.connection.location #=> String
resp.connection.type #=> String
resp.connection.state #=> String, one of "available", "requested", "pending", "down", "deleting", "deleted", "failed", "updating"
resp.connection.shared_id #=> String
resp.connection.billing_tier #=> Integer
resp.connection. #=> String
resp.connection.activation_key #=> String
resp.connection.tags #=> Hash
resp.connection.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :attach_point (required, Types::AttachPoint)

    The Attach Point to which the connection should be associated.

  • :activation_key (required, String)

    An Activation Key that was generated on a supported partner’s portal. This key captures the desired parameters from the initial creation request.

    The details of this request can be described using with DescribeConnectionProposal.

  • :description (String)

    A description to distinguish this Connection.

  • :tags (Hash<String,String>)

    The tags to associate with the resulting Connection.

  • :client_token (String)

    Idempotency token used for the request.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

Returns:

See Also:



596
597
598
599
# File 'lib/aws-sdk-interconnect/client.rb', line 596

def accept_connection_proposal(params = {}, options = {})
  req = build_request(:accept_connection_proposal, params)
  req.send_request(options)
end

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
# File 'lib/aws-sdk-interconnect/client.rb', line 1656

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::Interconnect')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-interconnect'
  context[:gem_version] = '1.0.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_connection(params = {}) ⇒ Types::CreateConnectionResponse

Initiates the process to create a Connection across the specified Environment.

The Environment dictates the specified partner and location to which the other end of the connection should attach. You can see a list of the available Environments by calling ListEnvironments

The Attach Point specifies where within the AWS Network your connection will logically connect.

After a successful call to this method, the resulting Connection will return an Activation Key which will need to be brought to the specific partner’s portal to confirm the Connection on both sides. (See Environment$activationPageUrl for a direct link to the partner portal).

Examples:

Example: Create Connection on specific environment


resp = client.create_connection({
  attach_point: {
    direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
  }, 
  bandwidth: "1Gbps", 
  environment_id: "mce-aws-acme-1", 
  remote_account: {
    identifier: "PartnerAccountDetails", 
  }, 
})

resp.to_h outputs the following:
{
  connection: {
    type: "Multicloud", 
    activation_key: "<Activation Key Data>", 
    arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
    attach_point: {
      direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
    }, 
    bandwidth: "1Gbps", 
    description: "My MultiCloud Connection", 
    environment_id: "mce-aws-acme-1", 
    id: "mcc-abc12345", 
    location: "acme-east", 
    owner_account: "000000000000", 
    provider: {
      cloud_service_provider: "acme", 
    }, 
    shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
    state: "requested", 
  }, 
}

Request syntax with placeholder values


resp = client.create_connection({
  description: "ConnectionDescription",
  bandwidth: "ConnectionBandwidth", # required
  attach_point: { # required
    direct_connect_gateway: "DirectConnectGatewayAttachPoint",
    arn: "AmazonResourceName",
  },
  environment_id: "EnvironmentId", # required
  remote_account: {
    identifier: "RemoteOwnerAccount",
  },
  tags: {
    "TagKey" => "TagValue",
  },
  client_token: "String",
})

Response structure


resp.connection.id #=> String
resp.connection.arn #=> String
resp.connection.description #=> String
resp.connection.bandwidth #=> String
resp.connection.attach_point.direct_connect_gateway #=> String
resp.connection.attach_point.arn #=> String
resp.connection.environment_id #=> String
resp.connection.provider.cloud_service_provider #=> String
resp.connection.provider.last_mile_provider #=> String
resp.connection.location #=> String
resp.connection.type #=> String
resp.connection.state #=> String, one of "available", "requested", "pending", "down", "deleting", "deleted", "failed", "updating"
resp.connection.shared_id #=> String
resp.connection.billing_tier #=> Integer
resp.connection. #=> String
resp.connection.activation_key #=> String
resp.connection.tags #=> Hash
resp.connection.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :description (String)

    A description to distinguish this Connection.

  • :bandwidth (required, String)

    The desired bandwidth of the requested Connection

  • :attach_point (required, Types::AttachPoint)

    The Attach Point to which the connection should be associated.“

  • :environment_id (required, String)

    The identifier of the Environment across which this Connection should be created.

    The available Environment objects can be determined using ListEnvironments.

  • :remote_account (Types::RemoteAccountIdentifier)

    Account and/or principal identifying information that can be verified by the partner of this specific Environment.

  • :tags (Hash<String,String>)

    The tag to associate with the resulting Connection.

  • :client_token (String)

    Idempotency token used for the request.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

Returns:

See Also:



731
732
733
734
# File 'lib/aws-sdk-interconnect/client.rb', line 731

def create_connection(params = {}, options = {})
  req = build_request(:create_connection, params)
  req.send_request(options)
end

#delete_connection(params = {}) ⇒ Types::DeleteConnectionResponse

Deletes an existing Connection with the supplied identifier.

This operation will also inform the remote partner of your intention to delete your connection. Note, the partner may still require you to delete to fully clean up resources, but the network connectivity provided by the Connection will cease to exist.

Examples:

Example: Delete Connection


resp = client.delete_connection({
  identifier: "mcc-abc12345", 
})

resp.to_h outputs the following:
{
  connection: {
    type: "Multicloud", 
    activation_key: "<Activation Key Data>", 
    arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
    attach_point: {
      direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
    }, 
    bandwidth: "2Gbps", 
    description: "changed Description", 
    environment_id: "mce-aws-acme-1", 
    id: "mcc-abc12345", 
    location: "acme-east", 
    owner_account: "000000000000", 
    provider: {
      cloud_service_provider: "acme", 
    }, 
    shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
    state: "deleting", 
  }, 
}

Request syntax with placeholder values


resp = client.delete_connection({
  identifier: "ConnectionId", # required
  client_token: "String",
})

Response structure


resp.connection.id #=> String
resp.connection.arn #=> String
resp.connection.description #=> String
resp.connection.bandwidth #=> String
resp.connection.attach_point.direct_connect_gateway #=> String
resp.connection.attach_point.arn #=> String
resp.connection.environment_id #=> String
resp.connection.provider.cloud_service_provider #=> String
resp.connection.provider.last_mile_provider #=> String
resp.connection.location #=> String
resp.connection.type #=> String
resp.connection.state #=> String, one of "available", "requested", "pending", "down", "deleting", "deleted", "failed", "updating"
resp.connection.shared_id #=> String
resp.connection.billing_tier #=> Integer
resp.connection. #=> String
resp.connection.activation_key #=> String
resp.connection.tags #=> Hash
resp.connection.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :identifier (required, String)

    The identifier of the Connection to be deleted.

  • :client_token (String)

    Idempotency token used for the request.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

Returns:

See Also:



818
819
820
821
# File 'lib/aws-sdk-interconnect/client.rb', line 818

def delete_connection(params = {}, options = {})
  req = build_request(:delete_connection, params)
  req.send_request(options)
end

#describe_connection_proposal(params = {}) ⇒ Types::DescribeConnectionProposalResponse

Describes the details of a connection proposal generated at a partner’s portal.

Examples:

Example: Describe Connection Proposal


resp = client.describe_connection_proposal({
  activation_key: "<Activation Key Data>", 
})

resp.to_h outputs the following:
{
  bandwidth: "1Gbps", 
  environment_id: "mce-aws-acme-1", 
  location: "acme-east", 
  provider: {
    cloud_service_provider: "acme", 
  }, 
}

Request syntax with placeholder values


resp = client.describe_connection_proposal({
  activation_key: "ActivationKey", # required
})

Response structure


resp.bandwidth #=> String
resp.environment_id #=> String
resp.provider.cloud_service_provider #=> String
resp.provider.last_mile_provider #=> String
resp.location #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :activation_key (required, String)

    An Activation Key that was generated on a supported partner’s portal. This key captures the desired parameters from the initial creation request.

Returns:

See Also:



873
874
875
876
# File 'lib/aws-sdk-interconnect/client.rb', line 873

def describe_connection_proposal(params = {}, options = {})
  req = build_request(:describe_connection_proposal, params)
  req.send_request(options)
end

#get_connection(params = {}) ⇒ Types::GetConnectionResponse

Describes the current state of a Connection resource as specified by the identifier.

The following waiters are defined for this operation (see #wait_until for detailed usage):

* connection_available
* connection_deleted

Examples:

Example: Get connection


resp = client.get_connection({
  identifier: "mcc-abc12345", 
})

resp.to_h outputs the following:
{
  connection: {
    type: "Multicloud", 
    activation_key: "<Activation Key Data>", 
    arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
    attach_point: {
      direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
    }, 
    bandwidth: "1Gbps", 
    description: "My MultiCloud Connection", 
    environment_id: "mce-aws-acme-1", 
    id: "mcc-abc12345", 
    location: "acme-east", 
    owner_account: "000000000000", 
    provider: {
      cloud_service_provider: "acme", 
    }, 
    shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
    state: "available", 
  }, 
}

Request syntax with placeholder values


resp = client.get_connection({
  identifier: "ConnectionId", # required
})

Response structure


resp.connection.id #=> String
resp.connection.arn #=> String
resp.connection.description #=> String
resp.connection.bandwidth #=> String
resp.connection.attach_point.direct_connect_gateway #=> String
resp.connection.attach_point.arn #=> String
resp.connection.environment_id #=> String
resp.connection.provider.cloud_service_provider #=> String
resp.connection.provider.last_mile_provider #=> String
resp.connection.location #=> String
resp.connection.type #=> String
resp.connection.state #=> String, one of "available", "requested", "pending", "down", "deleting", "deleted", "failed", "updating"
resp.connection.shared_id #=> String
resp.connection.billing_tier #=> Integer
resp.connection. #=> String
resp.connection.activation_key #=> String
resp.connection.tags #=> Hash
resp.connection.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :identifier (required, String)

    The identifier of the requested Connection

Returns:

See Also:



955
956
957
958
# File 'lib/aws-sdk-interconnect/client.rb', line 955

def get_connection(params = {}, options = {})
  req = build_request(:get_connection, params)
  req.send_request(options)
end

#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse

Describes a specific Environment

Examples:

Example: Get a specific environment


resp = client.get_environment({
  id: "mce-aws-acme-1", 
})

resp.to_h outputs the following:
{
  environment: {
    type: "Multicloud", 
    bandwidths: {
      available: [
        "1Gbps", 
      ], 
      supported: [
        "1Gbps", 
        "2Gbps", 
      ], 
    }, 
    environment_id: "mce-aws-acme-1", 
    location: "acme-east", 
    provider: {
      cloud_service_provider: "acme", 
    }, 
    state: "available", 
  }, 
}

Request syntax with placeholder values


resp = client.get_environment({
  id: "EnvironmentId", # required
})

Response structure


resp.environment.provider.cloud_service_provider #=> String
resp.environment.provider.last_mile_provider #=> String
resp.environment.location #=> String
resp.environment.environment_id #=> String
resp.environment.state #=> String, one of "available", "limited", "unavailable"
resp.environment.bandwidths.available #=> Array
resp.environment.bandwidths.available[0] #=> String
resp.environment.bandwidths.supported #=> Array
resp.environment.bandwidths.supported[0] #=> String
resp.environment.type #=> String
resp.environment.activation_page_url #=> String
resp.environment.remote_identifier_type #=> String, one of "account", "email"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The identifier of the specific Environment to describe.

Returns:

See Also:



1023
1024
1025
1026
# File 'lib/aws-sdk-interconnect/client.rb', line 1023

def get_environment(params = {}, options = {})
  req = build_request(:get_environment, params)
  req.send_request(options)
end

#list_attach_points(params = {}) ⇒ Types::ListAttachPointsResponse

Lists all Attach Points the caller has access to that are valid for the specified Environment.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Example: List Attach Points


resp = client.list_attach_points({
  environment_id: "mce-aws-acme-1", 
})

resp.to_h outputs the following:
{
  attach_points: [
    {
      name: "My DirectConnectGateway", 
      type: "DirectConnectGateway", 
      identifier: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
    }, 
  ], 
}

Request syntax with placeholder values


resp = client.list_attach_points({
  environment_id: "EnvironmentId", # required
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.attach_points #=> Array
resp.attach_points[0].type #=> String, one of "DirectConnectGateway"
resp.attach_points[0].identifier #=> String
resp.attach_points[0].name #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :environment_id (required, String)

    The identifier of the Environment for which to list valid Attach Points.

  • :max_results (Integer)

    The max number of list results in a single paginated response.

  • :next_token (String)

    A pagination token from a previous paginated response indicating you wish to get the next page.

Returns:

See Also:



1087
1088
1089
1090
# File 'lib/aws-sdk-interconnect/client.rb', line 1087

def list_attach_points(params = {}, options = {})
  req = build_request(:list_attach_points, params)
  req.send_request(options)
end

#list_connections(params = {}) ⇒ Types::ListConnectionsResponse

Lists all connection objects to which the caller has access.

Allows for optional filtering by the following properties:

  • ‘state`

  • ‘environmentId`

  • ‘provider`

  • ‘attach point`

Only Connection objects matching all filters will be returned.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Example: List All Connections


resp = client.list_connections({
})

resp.to_h outputs the following:
{
  connections: [
    {
      type: "Multicloud", 
      arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
      attach_point: {
        direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
      }, 
      bandwidth: "1Gbps", 
      description: "My MultiCloud Connection", 
      environment_id: "mce-aws-acme-1", 
      id: "mcc-abc12345", 
      location: "acme-east", 
      provider: {
        cloud_service_provider: "acme", 
      }, 
      shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
      state: "available", 
    }, 
    {
      type: "LastMile", 
      arn: "arn:aws:interconnect:us-east-1:000000000000:connection/lmcc-xyz98765", 
      attach_point: {
        direct_connect_gateway: "244FB7E5-3C56-4F7D-AAB9-E35F70764154", 
      }, 
      bandwidth: "1Gbps", 
      description: "My LastMile  Connection", 
      environment_id: "mce-aws-lastmile-1", 
      id: "lmcc-xyz98765", 
      location: "lastmile-east", 
      provider: {
        last_mile_provider: "lastmile", 
      }, 
      shared_id: "27C2CDD8-8FDF-402D-9DFF-92F66ED7C7FC", 
      state: "pending", 
    }, 
  ], 
}

Example: List Connections in available state


resp = client.list_connections({
  state: "available", 
})

resp.to_h outputs the following:
{
  connections: [
    {
      type: "Multicloud", 
      arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
      attach_point: {
        direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
      }, 
      bandwidth: "1Gbps", 
      description: "My MultiCloud Connection", 
      environment_id: "mce-aws-acme-1", 
      id: "mcc-abc12345", 
      location: "acme-east", 
      provider: {
        cloud_service_provider: "acme", 
      }, 
      shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
      state: "available", 
    }, 
  ], 
}

Example: List Connections on specific Environment


resp = client.list_connections({
  environment_id: "mce-aws-acme-1", 
})

resp.to_h outputs the following:
{
  connections: [
    {
      type: "LastMile", 
      arn: "arn:aws:interconnect:us-east-1:000000000000:connection/lmcc-xyz98765", 
      attach_point: {
        direct_connect_gateway: "244FB7E5-3C56-4F7D-AAB9-E35F70764154", 
      }, 
      bandwidth: "1Gbps", 
      description: "My LastMile  Connection", 
      environment_id: "mce-aws-lastmile-1", 
      id: "lmcc-xyz98765", 
      location: "lastmile-east", 
      provider: {
        last_mile_provider: "lastmile", 
      }, 
      shared_id: "27C2CDD8-8FDF-402D-9DFF-92F66ED7C7FC", 
      state: "pending", 
    }, 
  ], 
}

Request syntax with placeholder values


resp = client.list_connections({
  max_results: 1,
  next_token: "NextToken",
  state: "available", # accepts available, requested, pending, down, deleting, deleted, failed, updating
  environment_id: "EnvironmentId",
  provider: {
    cloud_service_provider: "CloudServiceProvider",
    last_mile_provider: "LastMileProvider",
  },
  attach_point: {
    direct_connect_gateway: "DirectConnectGatewayAttachPoint",
    arn: "AmazonResourceName",
  },
})

Response structure


resp.connections #=> Array
resp.connections[0].id #=> String
resp.connections[0].arn #=> String
resp.connections[0].description #=> String
resp.connections[0].bandwidth #=> String
resp.connections[0].attach_point.direct_connect_gateway #=> String
resp.connections[0].attach_point.arn #=> String
resp.connections[0].environment_id #=> String
resp.connections[0].provider.cloud_service_provider #=> String
resp.connections[0].provider.last_mile_provider #=> String
resp.connections[0].location #=> String
resp.connections[0].type #=> String
resp.connections[0].state #=> String, one of "available", "requested", "pending", "down", "deleting", "deleted", "failed", "updating"
resp.connections[0].shared_id #=> String
resp.connections[0].billing_tier #=> Integer
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :max_results (Integer)

    The max number of list results in a single paginated response.

  • :next_token (String)

    A pagination token from a previous paginated response indicating you wish to get the next page of results.

  • :state (String)

    Filter the results to only include Connection objects in the given Connection$state.

  • :environment_id (String)

    Filter the results to only include Connection objects on the given Environment.

  • :provider (Types::Provider)

    Filter the results to only include Connection objects to the given Provider.

  • :attach_point (Types::AttachPoint)

    Filter results to only include Connection objects attached to the given AttachPoint.

Returns:

See Also:



1280
1281
1282
1283
# File 'lib/aws-sdk-interconnect/client.rb', line 1280

def list_connections(params = {}, options = {})
  req = build_request(:list_connections, params)
  req.send_request(options)
end

#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse

Lists all of the environments that can produce connections that will land in the called AWS region.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Example: List All Environments


resp = client.list_environments({
})

resp.to_h outputs the following:
{
  environments: [
    {
      type: "Multicloud", 
      bandwidths: {
        available: [
          "1Gbps", 
        ], 
        supported: [
          "1Gbps", 
          "2Gbps", 
        ], 
      }, 
      environment_id: "mce-aws-acme-1", 
      location: "acme-east", 
      provider: {
        cloud_service_provider: "acme", 
      }, 
      state: "available", 
    }, 
    {
      type: "LastMile", 
      bandwidths: {
        available: [
          "1Gbps", 
        ], 
        supported: [
          "1Gbps", 
          "2Gbps", 
        ], 
      }, 
      environment_id: "mce-aws-lastmile-1", 
      location: "lastmile-east", 
      provider: {
        cloud_service_provider: "acme", 
      }, 
      state: "available", 
    }, 
  ], 
}

Request syntax with placeholder values


resp = client.list_environments({
  max_results: 1,
  next_token: "NextToken",
  provider: {
    cloud_service_provider: "CloudServiceProvider",
    last_mile_provider: "LastMileProvider",
  },
  location: "Location",
})

Response structure


resp.environments #=> Array
resp.environments[0].provider.cloud_service_provider #=> String
resp.environments[0].provider.last_mile_provider #=> String
resp.environments[0].location #=> String
resp.environments[0].environment_id #=> String
resp.environments[0].state #=> String, one of "available", "limited", "unavailable"
resp.environments[0].bandwidths.available #=> Array
resp.environments[0].bandwidths.available[0] #=> String
resp.environments[0].bandwidths.supported #=> Array
resp.environments[0].bandwidths.supported[0] #=> String
resp.environments[0].type #=> String
resp.environments[0].activation_page_url #=> String
resp.environments[0].remote_identifier_type #=> String, one of "account", "email"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :max_results (Integer)

    The max number of list results in a single paginated response.

  • :next_token (String)

    A pagination token from a previous paginated response indicating you wish to get the next page of results.

  • :provider (Types::Provider)

    Filter results to only include Environment objects that connect to the Provider.

  • :location (String)

    Filter results to only include Environment objects that connect to a given location distiguisher.

Returns:

See Also:



1391
1392
1393
1394
# File 'lib/aws-sdk-interconnect/client.rb', line 1391

def list_environments(params = {}, options = {})
  req = build_request(:list_environments, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse

List all current tags on the specified resource. Currently this supports Connection resources.

Examples:

Example: List Tags


resp = client.list_tags_for_resource({
  arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
})

resp.to_h outputs the following:
{
  tags: {
    "TagKey1" => "TagValue1", 
    "TagKey2" => "TagValue2", 
  }, 
}

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  arn: "AmazonResourceName", # required
})

Response structure


resp.tags #=> Hash
resp.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :arn (required, String)

    The resource ARN for which to list tags.

Returns:

See Also:



1436
1437
1438
1439
# File 'lib/aws-sdk-interconnect/client.rb', line 1436

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Add new tags to the specified resource.

Examples:

Example: Apply Tags


resp = client.tag_resource({
  arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
  tags: {
    "TagKey1" => "TagValue1", 
    "TagKey2" => "TagValue2", 
  }, 
})

resp.to_h outputs the following:
{
}

Request syntax with placeholder values


resp = client.tag_resource({
  arn: "AmazonResourceName", # required
  tags: { # required
    "TagKey" => "TagValue",
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :arn (required, String)

    The ARN of the resource that should receive the new tags.

  • :tags (required, Hash<String,String>)

    A map of tags to apply to the specified resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1479
1480
1481
1482
# File 'lib/aws-sdk-interconnect/client.rb', line 1479

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Removes tags from the specified resource.

Examples:

Example: Remove Tags


resp = client.untag_resource({
  arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
  tag_keys: [
    "TagKey1", 
    "TagKey2", 
  ], 
})

resp.to_h outputs the following:
{
}

Request syntax with placeholder values


resp = client.untag_resource({
  arn: "AmazonResourceName", # required
  tag_keys: ["TagKey"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :arn (required, String)

    The ARN of the resource from which the specified tags should be removed.

  • :tag_keys (required, Array<String>)

    The list of tag keys that should be removed from the resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1521
1522
1523
1524
# File 'lib/aws-sdk-interconnect/client.rb', line 1521

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#update_connection(params = {}) ⇒ Types::UpdateConnectionResponse

Modifies an existing connection. Currently we support modifications to the connection’s description and/or bandwidth.

Examples:

Example: Update Connection Description


resp = client.update_connection({
  description: "Changed Description", 
  identifier: "mcc-abc12345", 
})

resp.to_h outputs the following:
{
  connection: {
    type: "Multicloud", 
    activation_key: "<Activation Key Data>", 
    arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
    attach_point: {
      direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
    }, 
    bandwidth: "1Gbps", 
    description: "changed Description", 
    environment_id: "mce-aws-acme-1", 
    id: "mcc-abc12345", 
    location: "acme-east", 
    owner_account: "000000000000", 
    provider: {
      cloud_service_provider: "acme", 
    }, 
    shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
    state: "available", 
  }, 
}

Example: Update Connection Bandwidth


resp = client.update_connection({
  bandwidth: "2Gbps", 
  identifier: "mcc-abc12345", 
})

resp.to_h outputs the following:
{
  connection: {
    type: "Multicloud", 
    activation_key: "<Activation Key Data>", 
    arn: "arn:aws:interconnect:us-east-1:000000000000:connection/mcc-abc12345", 
    attach_point: {
      direct_connect_gateway: "90392BE3-219C-47FD-BBA5-03DF76D2542A", 
    }, 
    bandwidth: "2Gbps", 
    description: "changed Description", 
    environment_id: "mce-aws-acme-1", 
    id: "mcc-abc12345", 
    location: "acme-east", 
    owner_account: "000000000000", 
    provider: {
      cloud_service_provider: "acme", 
    }, 
    shared_id: "B0615F4D-E588-47AD-9D04-1449EAA61C91", 
    state: "updating", 
  }, 
}

Request syntax with placeholder values


resp = client.update_connection({
  identifier: "ConnectionId", # required
  description: "ConnectionDescription",
  bandwidth: "ConnectionBandwidth",
  client_token: "String",
})

Response structure


resp.connection.id #=> String
resp.connection.arn #=> String
resp.connection.description #=> String
resp.connection.bandwidth #=> String
resp.connection.attach_point.direct_connect_gateway #=> String
resp.connection.attach_point.arn #=> String
resp.connection.environment_id #=> String
resp.connection.provider.cloud_service_provider #=> String
resp.connection.provider.last_mile_provider #=> String
resp.connection.location #=> String
resp.connection.type #=> String
resp.connection.state #=> String, one of "available", "requested", "pending", "down", "deleting", "deleted", "failed", "updating"
resp.connection.shared_id #=> String
resp.connection.billing_tier #=> Integer
resp.connection. #=> String
resp.connection.activation_key #=> String
resp.connection.tags #=> Hash
resp.connection.tags["TagKey"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :identifier (required, String)

    The identifier of the Connection that should be updated.

  • :description (String)

    An updated description to apply to the Connection

  • :bandwidth (String)

    Request a new bandwidth size on the given Connection.

    Note that changes to the size may be subject to additional policy, and does require the remote partner provider to acknowledge and permit this new bandwidth size.

  • :client_token (String)

    Idempotency token used for the request.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

Returns:

See Also:



1647
1648
1649
1650
# File 'lib/aws-sdk-interconnect/client.rb', line 1647

def update_connection(params = {}, options = {})
  req = build_request(:update_connection, params)
  req.send_request(options)
end

#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean

Polls an API operation until a resource enters a desired state.

## Basic Usage

A waiter will call an API operation until:

  • It is successful

  • It enters a terminal state

  • It makes the maximum number of attempts

In between attempts, the waiter will sleep.

# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)

## Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.

# poll for ~25 seconds
client.wait_until(waiter_name, params, {
  max_attempts: 5,
  delay: 5,
})

## Callbacks

You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.

started_at = Time.now
client.wait_until(waiter_name, params, {

  # disable max attempts
  max_attempts: nil,

  # poll for 1 hour, instead of a number of attempts
  before_wait: -> (attempts, response) do
    throw :failure if Time.now - started_at > 3600
  end
})

## Handling Errors

When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.

begin
  client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

## Valid Waiters

The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.

| waiter_name | params | :delay | :max_attempts | | ——————– | ———————– | ——– | ————- | | connection_available | #get_connection | 30 | 5 | | connection_deleted | #get_connection | 30 | 5 |

Parameters:

  • waiter_name (Symbol)
  • params (Hash) (defaults to: {})

    ({})

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :max_attempts (Integer)
  • :delay (Integer)
  • :before_attempt (Proc)
  • :before_wait (Proc)

Yields:

  • (w.waiter)

Returns:

  • (Boolean)

    Returns ‘true` if the waiter was successful.

Raises:

  • (Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

  • (Errors::TooManyAttemptsError)

    Raised when the configured maximum number of attempts have been made, and the waiter is not yet successful.

  • (Errors::UnexpectedError)

    Raised when an error is encounted while polling for a resource that is not expected.

  • (Errors::NoSuchWaiterError)

    Raised when you request to wait for an unknown state.



1763
1764
1765
1766
1767
# File 'lib/aws-sdk-interconnect/client.rb', line 1763

def wait_until(waiter_name, params = {}, options = {})
  w = waiter(waiter_name, options)
  yield(w.waiter) if block_given? # deprecated
  w.wait(params)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1771
1772
1773
# File 'lib/aws-sdk-interconnect/client.rb', line 1771

def waiter_names
  waiters.keys
end