Module: Aws::Interconnect::Types
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Defined Under Namespace
Classes: AcceptConnectionProposalRequest, AcceptConnectionProposalResponse, AccessDeniedException, AttachPoint, AttachPointDescriptor, Bandwidths, Connection, ConnectionSummary, CreateConnectionRequest, CreateConnectionResponse, DeleteConnectionRequest, DeleteConnectionResponse, DescribeConnectionProposalRequest, DescribeConnectionProposalResponse, Environment, GetConnectionRequest, GetConnectionResponse, GetEnvironmentRequest, GetEnvironmentResponse, InterconnectClientException, InterconnectServerException, InterconnectValidationException, ListAttachPointsRequest, ListAttachPointsResponse, ListConnectionsRequest, ListConnectionsResponse, ListEnvironmentsRequest, ListEnvironmentsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, Provider, RemoteAccountIdentifier, ResourceNotFoundException, ServiceQuotaExceededException, TagResourceRequest, TagResourceResponse, ThrottlingException, UntagResourceRequest, UntagResourceResponse, UpdateConnectionRequest, UpdateConnectionResponse
Instance Attribute Summary collapse
-
#arn ⇒ String
Identifies an attach point by full ARN.
-
#cloud_service_provider ⇒ String
The provider’s name.
-
#direct_connect_gateway ⇒ String
Identifies an DirectConnect Gateway attach point by DirectConnectGatewayID.
-
#identifier ⇒ String
A generic bit of identifying information.
-
#last_mile_provider ⇒ String
The provider’s name.
Instance Attribute Details
#arn ⇒ String
Identifies an attach point by full ARN.
96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/aws-sdk-interconnect/types.rb', line 96 class AttachPoint < Struct.new( :direct_connect_gateway, :arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectConnectGateway < AttachPoint; end class Arn < AttachPoint; end class Unknown < AttachPoint; end end |
#cloud_service_provider ⇒ String
The provider’s name. Specifically, connections to/from this Cloud Service Provider will be considered Multicloud connections.
832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/aws-sdk-interconnect/types.rb', line 832 class Provider < Struct.new( :cloud_service_provider, :last_mile_provider, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CloudServiceProvider < Provider; end class LastMileProvider < Provider; end class Unknown < Provider; end end |
#direct_connect_gateway ⇒ String
Identifies an DirectConnect Gateway attach point by DirectConnectGatewayID.
96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/aws-sdk-interconnect/types.rb', line 96 class AttachPoint < Struct.new( :direct_connect_gateway, :arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectConnectGateway < AttachPoint; end class Arn < AttachPoint; end class Unknown < AttachPoint; end end |
#identifier ⇒ String
A generic bit of identifying information. Can be used in place of any of the more specific types.
857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-interconnect/types.rb', line 857 class RemoteAccountIdentifier < Struct.new( :identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Identifier < RemoteAccountIdentifier; end class Unknown < RemoteAccountIdentifier; end end |
#last_mile_provider ⇒ String
The provider’s name. Specifically, connections to/from this Last Mile Provider will be considered LastMile connections.
832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/aws-sdk-interconnect/types.rb', line 832 class Provider < Struct.new( :cloud_service_provider, :last_mile_provider, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CloudServiceProvider < Provider; end class LastMileProvider < Provider; end class Unknown < Provider; end end |