Class: Aws::Interconnect::Types::AcceptConnectionProposalRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::AcceptConnectionProposalRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:activation_key]
Instance Attribute Summary collapse
-
#activation_key ⇒ String
An Activation Key that was generated on a supported partner’s portal.
-
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.
-
#client_token ⇒ String
Idempotency token used for the request.
-
#description ⇒ String
A description to distinguish this Connection.
-
#tags ⇒ Hash<String,String>
The tags to associate with the resulting Connection.
Instance Attribute Details
#activation_key ⇒ String
An Activation Key that was generated on a supported partner’s portal. This key captures the desired parameters from the initial creation request.
The details of this request can be described using with DescribeConnectionProposal.
43 44 45 46 47 48 49 50 51 |
# File 'lib/aws-sdk-interconnect/types.rb', line 43 class AcceptConnectionProposalRequest < Struct.new( :attach_point, :activation_key, :description, :tags, :client_token) SENSITIVE = [:activation_key] include Aws::Structure end |
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.
43 44 45 46 47 48 49 50 51 |
# File 'lib/aws-sdk-interconnect/types.rb', line 43 class AcceptConnectionProposalRequest < Struct.new( :attach_point, :activation_key, :description, :tags, :client_token) SENSITIVE = [:activation_key] include Aws::Structure end |
#client_token ⇒ String
Idempotency token used for the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
43 44 45 46 47 48 49 50 51 |
# File 'lib/aws-sdk-interconnect/types.rb', line 43 class AcceptConnectionProposalRequest < Struct.new( :attach_point, :activation_key, :description, :tags, :client_token) SENSITIVE = [:activation_key] include Aws::Structure end |
#description ⇒ String
A description to distinguish this Connection.
43 44 45 46 47 48 49 50 51 |
# File 'lib/aws-sdk-interconnect/types.rb', line 43 class AcceptConnectionProposalRequest < Struct.new( :attach_point, :activation_key, :description, :tags, :client_token) SENSITIVE = [:activation_key] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to associate with the resulting Connection.
43 44 45 46 47 48 49 50 51 |
# File 'lib/aws-sdk-interconnect/types.rb', line 43 class AcceptConnectionProposalRequest < Struct.new( :attach_point, :activation_key, :description, :tags, :client_token) SENSITIVE = [:activation_key] include Aws::Structure end |