Class: Aws::Interconnect::Types::AttachPoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::AttachPoint
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Note:
AttachPoint is a union - when making an API calls you must set exactly one of the members.
Note:
AttachPoint is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AttachPoint corresponding to the set member.
Identifies an attach point to use with a Connection.
Direct Known Subclasses
Defined Under Namespace
Classes: Arn, DirectConnectGateway, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Identifies an attach point by full ARN.
-
#direct_connect_gateway ⇒ String
Identifies an DirectConnect Gateway attach point by DirectConnectGatewayID.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#arn ⇒ String
Identifies an attach point by full ARN.
96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/aws-sdk-interconnect/types.rb', line 96 class AttachPoint < Struct.new( :direct_connect_gateway, :arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectConnectGateway < AttachPoint; end class Arn < AttachPoint; end class Unknown < AttachPoint; end end |
#direct_connect_gateway ⇒ String
Identifies an DirectConnect Gateway attach point by DirectConnectGatewayID.
96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/aws-sdk-interconnect/types.rb', line 96 class AttachPoint < Struct.new( :direct_connect_gateway, :arn, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DirectConnectGateway < AttachPoint; end class Arn < AttachPoint; end class Unknown < AttachPoint; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
96 97 98 |
# File 'lib/aws-sdk-interconnect/types.rb', line 96 def unknown @unknown end |