Class: Aws::Interconnect::Types::AttachPointDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::AttachPointDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Describes a possible Attach Point for a Connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The identifier for the specific type of the AttachPoint.
-
#name ⇒ String
The descriptive name of the identifier attach point.
-
#type ⇒ String
The type of this AttachPoint, which will dictate the syntax of the identifier.
Instance Attribute Details
#identifier ⇒ String
The identifier for the specific type of the AttachPoint.
132 133 134 135 136 137 138 |
# File 'lib/aws-sdk-interconnect/types.rb', line 132 class AttachPointDescriptor < Struct.new( :type, :identifier, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The descriptive name of the identifier attach point.
132 133 134 135 136 137 138 |
# File 'lib/aws-sdk-interconnect/types.rb', line 132 class AttachPointDescriptor < Struct.new( :type, :identifier, :name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of this AttachPoint, which will dictate the syntax of the identifier.
Current types include:
-
ARN
-
DirectConnect Gateway
132 133 134 135 136 137 138 |
# File 'lib/aws-sdk-interconnect/types.rb', line 132 class AttachPointDescriptor < Struct.new( :type, :identifier, :name) SENSITIVE = [] include Aws::Structure end |