Class: Aws::Interconnect::Types::Bandwidths
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::Bandwidths
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Contains the details about the available and supported bandwidths.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#available ⇒ Array<String>
The list of currently available bandwidths.
-
#supported ⇒ Array<String>
The list of all bandwidths that this environment plans to support.
Instance Attribute Details
#available ⇒ Array<String>
The list of currently available bandwidths.
152 153 154 155 156 157 |
# File 'lib/aws-sdk-interconnect/types.rb', line 152 class Bandwidths < Struct.new( :available, :supported) SENSITIVE = [] include Aws::Structure end |
#supported ⇒ Array<String>
The list of all bandwidths that this environment plans to support
152 153 154 155 156 157 |
# File 'lib/aws-sdk-interconnect/types.rb', line 152 class Bandwidths < Struct.new( :available, :supported) SENSITIVE = [] include Aws::Structure end |