Class: Aws::Interconnect::Types::Connection
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::Connection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
The object describing the provided connectivity from the AWS region to the partner location.
Constant Summary collapse
- SENSITIVE =
[:activation_key]
Instance Attribute Summary collapse
-
#activation_key ⇒ String
The Activation Key associated to this connection.
-
#arn ⇒ String
An ARN of a Connection object.
-
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.“.
-
#bandwidth ⇒ String
The specific selected bandwidth of this connection.
-
#billing_tier ⇒ Integer
The billing tier this connection is currently assigned.
-
#description ⇒ String
A descriptive name for the connection.
-
#environment_id ⇒ String
The specific Environment this connection is placed upon.
-
#id ⇒ String
The short identifier of the connection object.
-
#location ⇒ String
The provider specific location on the remote side of this Connection.
-
#owner_account ⇒ String
The account that owns this Connection.
-
#provider ⇒ Types::Provider
The provider on the remote side of this Connection.
-
#shared_id ⇒ String
An identifier used by both AWS and the remote partner to identify the specific connection.
-
#state ⇒ String
-
‘requested`: The initial state of a connection.
-
-
#tags ⇒ Hash<String,String>
The tags on the Connection.
-
#type ⇒ String
The specific product type of this Connection.
Instance Attribute Details
#activation_key ⇒ String
The Activation Key associated to this connection.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#arn ⇒ String
An ARN of a Connection object.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.“
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#bandwidth ⇒ String
The specific selected bandwidth of this connection.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#billing_tier ⇒ Integer
The billing tier this connection is currently assigned.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#description ⇒ String
A descriptive name for the connection.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#environment_id ⇒ String
The specific Environment this connection is placed upon.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#id ⇒ String
The short identifier of the connection object.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#location ⇒ String
The provider specific location on the remote side of this Connection
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#owner_account ⇒ String
The account that owns this Connection
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#provider ⇒ Types::Provider
The provider on the remote side of this Connection.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#shared_id ⇒ String
An identifier used by both AWS and the remote partner to identify the specific connection.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#state ⇒ String
-
‘requested`: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal.
-
‘pending`: The connection has been accepted and is being provisioned between AWS and the Partner.
-
‘available`: The connection has been fully provisioned between AWS and the Partner.
-
‘deleting`: The connection is being deleted.
-
‘deleted`: The connection has been deleted.
-
‘failed`: The connection has failed to be created.
-
‘updating`: The connection is being updated.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags on the Connection
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |
#type ⇒ String
The specific product type of this Connection.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/aws-sdk-interconnect/types.rb', line 241 class Connection < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier, :owner_account, :activation_key, :tags) SENSITIVE = [:activation_key] include Aws::Structure end |