Class: Aws::Interconnect::Types::ConnectionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::ConnectionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Summarized view of a Connection object.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Connection.
-
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.
-
#bandwidth ⇒ String
The bandwidth of the Connection.
-
#billing_tier ⇒ Integer
The billing tier this connection is currently assigned.
-
#description ⇒ String
A descriptive name of the Connection.
-
#environment_id ⇒ String
The Environment that this Connection is created on.
-
#id ⇒ String
The identifier of the requested Connection.
-
#location ⇒ String
The provider specific location at the remote end of this Connection.
-
#provider ⇒ Types::Provider
The provider on the remote end of this Connection.
-
#shared_id ⇒ String
An identifier used by both AWS and the remote partner to identify the specific connection.
-
#state ⇒ String
-
‘requested`: The initial state of a connection.
-
-
#type ⇒ String
The product variant supplied by this resource.
Instance Attribute Details
#arn ⇒ String
The ARN of the Connection
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#bandwidth ⇒ String
The bandwidth of the Connection
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#billing_tier ⇒ Integer
The billing tier this connection is currently assigned.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A descriptive name of the Connection
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The Environment that this Connection is created on.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the requested Connection
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The provider specific location at the remote end of this Connection
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ Types::Provider
The provider on the remote end of this Connection
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#shared_id ⇒ String
An identifier used by both AWS and the remote partner to identify the specific connection.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
-
‘requested`: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal.
-
‘pending`: The connection has been accepted and is being provisioned between AWS and the Partner.
-
‘available`: The connection has been fully provisioned between AWS and the Partner.
-
‘deleting`: The connection is being deleted.
-
‘deleted`: The connection has been deleted.
-
‘failed`: The connection has failed to be created.
-
‘updating`: The connection is being updated.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The product variant supplied by this resource.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/aws-sdk-interconnect/types.rb', line 330 class ConnectionSummary < Struct.new( :id, :arn, :description, :bandwidth, :attach_point, :environment_id, :provider, :location, :type, :state, :shared_id, :billing_tier) SENSITIVE = [] include Aws::Structure end |