Class: Aws::Interconnect::Types::CreateConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::CreateConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.“.
-
#bandwidth ⇒ String
The desired bandwidth of the requested Connection.
-
#client_token ⇒ String
Idempotency token used for the request.
-
#description ⇒ String
A description to distinguish this Connection.
-
#environment_id ⇒ String
The identifier of the Environment across which this Connection should be created.
-
#remote_account ⇒ Types::RemoteAccountIdentifier
Account and/or principal identifying information that can be verified by the partner of this specific Environment.
-
#tags ⇒ Hash<String,String>
The tag to associate with the resulting Connection.
Instance Attribute Details
#attach_point ⇒ Types::AttachPoint
The Attach Point to which the connection should be associated.“
385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-interconnect/types.rb', line 385 class CreateConnectionRequest < Struct.new( :description, :bandwidth, :attach_point, :environment_id, :remote_account, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#bandwidth ⇒ String
The desired bandwidth of the requested Connection
385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-interconnect/types.rb', line 385 class CreateConnectionRequest < Struct.new( :description, :bandwidth, :attach_point, :environment_id, :remote_account, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Idempotency token used for the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-interconnect/types.rb', line 385 class CreateConnectionRequest < Struct.new( :description, :bandwidth, :attach_point, :environment_id, :remote_account, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description to distinguish this Connection.
385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-interconnect/types.rb', line 385 class CreateConnectionRequest < Struct.new( :description, :bandwidth, :attach_point, :environment_id, :remote_account, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the Environment across which this Connection should be created.
The available Environment objects can be determined using ListEnvironments.
385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-interconnect/types.rb', line 385 class CreateConnectionRequest < Struct.new( :description, :bandwidth, :attach_point, :environment_id, :remote_account, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#remote_account ⇒ Types::RemoteAccountIdentifier
Account and/or principal identifying information that can be verified by the partner of this specific Environment.
385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-interconnect/types.rb', line 385 class CreateConnectionRequest < Struct.new( :description, :bandwidth, :attach_point, :environment_id, :remote_account, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tag to associate with the resulting Connection.
385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/aws-sdk-interconnect/types.rb', line 385 class CreateConnectionRequest < Struct.new( :description, :bandwidth, :attach_point, :environment_id, :remote_account, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |