Class: Aws::Interconnect::Types::DescribeConnectionProposalResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::DescribeConnectionProposalResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth ⇒ String
The bandwidth of the proposed Connection.
-
#environment_id ⇒ String
The identifier of the Environment upon which the Connection would be placed if this proposal were accepted.
-
#location ⇒ String
The partner specific location distinguisher of the specific Environment of the proposal.
-
#provider ⇒ Types::Provider
The partner provider of the specific Environment of the proposal.
Instance Attribute Details
#bandwidth ⇒ String
The bandwidth of the proposed Connection.
475 476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-interconnect/types.rb', line 475 class DescribeConnectionProposalResponse < Struct.new( :bandwidth, :environment_id, :provider, :location) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the Environment upon which the Connection would be placed if this proposal were accepted.
475 476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-interconnect/types.rb', line 475 class DescribeConnectionProposalResponse < Struct.new( :bandwidth, :environment_id, :provider, :location) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The partner specific location distinguisher of the specific Environment of the proposal.
475 476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-interconnect/types.rb', line 475 class DescribeConnectionProposalResponse < Struct.new( :bandwidth, :environment_id, :provider, :location) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ Types::Provider
The partner provider of the specific Environment of the proposal.
475 476 477 478 479 480 481 482 |
# File 'lib/aws-sdk-interconnect/types.rb', line 475 class DescribeConnectionProposalResponse < Struct.new( :bandwidth, :environment_id, :provider, :location) SENSITIVE = [] include Aws::Structure end |