Class: Aws::Interconnect::Types::Environment
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::Environment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Defines the logical topology that an AWS Interconnect Connection is created upon.
Specifically, an Environment defines the partner The remote Cloud Service Provider of this resource. or The remote Last Mile Provider of this resource. and the region or location specification to which an AWS Interconnect Connection can be made.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activation_page_url ⇒ String
An HTTPS URL on the remote partner portal where the Activation Key should be brought to complete the creation process.
-
#bandwidths ⇒ Types::Bandwidths
The sets of bandwidths that are available and supported on this environment.
-
#environment_id ⇒ String
The identifier of this Environment.
-
#location ⇒ String
The provider specific location on the remote side of this Connection.
-
#provider ⇒ Types::Provider
The provider on the remote side of this Connection.
-
#remote_identifier_type ⇒ String
The type of identifying information that should be supplied to the ‘remoteAccount` parameter of a CreateConnection call for this specific Environment.
-
#state ⇒ String
The state of the Environment.
-
#type ⇒ String
The specific product type of Connection objects provided by this Environment.
Instance Attribute Details
#activation_page_url ⇒ String
An HTTPS URL on the remote partner portal where the Activation Key should be brought to complete the creation process.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |
#bandwidths ⇒ Types::Bandwidths
The sets of bandwidths that are available and supported on this environment.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The identifier of this Environment
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The provider specific location on the remote side of this Connection.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ Types::Provider
The provider on the remote side of this Connection.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |
#remote_identifier_type ⇒ String
The type of identifying information that should be supplied to the ‘remoteAccount` parameter of a CreateConnection call for this specific Environment.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the Environment. Possible values:
-
‘available`: The environment is available and new Connection objects can be requested.
-
‘limited`: The environment is available, but overall capacity is limited. The set of available bandwidths
-
‘unavailable`: The environment is currently unavailable.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The specific product type of Connection objects provided by this Environment.
540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/aws-sdk-interconnect/types.rb', line 540 class Environment < Struct.new( :provider, :location, :environment_id, :state, :bandwidths, :type, :activation_page_url, :remote_identifier_type) SENSITIVE = [] include Aws::Structure end |