Class: Aws::Interconnect::Types::ListConnectionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::ListConnectionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attach_point ⇒ Types::AttachPoint
Filter results to only include Connection objects attached to the given AttachPoint.
-
#environment_id ⇒ String
Filter the results to only include Connection objects on the given Environment.
-
#max_results ⇒ Integer
The max number of list results in a single paginated response.
-
#next_token ⇒ String
A pagination token from a previous paginated response indicating you wish to get the next page of results.
-
#provider ⇒ Types::Provider
Filter the results to only include Connection objects to the given Provider.
-
#state ⇒ String
Filter the results to only include Connection objects in the given Connection$state.
Instance Attribute Details
#attach_point ⇒ Types::AttachPoint
Filter results to only include Connection objects attached to the given AttachPoint.
713 714 715 716 717 718 719 720 721 722 |
# File 'lib/aws-sdk-interconnect/types.rb', line 713 class ListConnectionsRequest < Struct.new( :max_results, :next_token, :state, :environment_id, :provider, :attach_point) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
Filter the results to only include Connection objects on the given Environment.
713 714 715 716 717 718 719 720 721 722 |
# File 'lib/aws-sdk-interconnect/types.rb', line 713 class ListConnectionsRequest < Struct.new( :max_results, :next_token, :state, :environment_id, :provider, :attach_point) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The max number of list results in a single paginated response.
713 714 715 716 717 718 719 720 721 722 |
# File 'lib/aws-sdk-interconnect/types.rb', line 713 class ListConnectionsRequest < Struct.new( :max_results, :next_token, :state, :environment_id, :provider, :attach_point) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token from a previous paginated response indicating you wish to get the next page of results.
713 714 715 716 717 718 719 720 721 722 |
# File 'lib/aws-sdk-interconnect/types.rb', line 713 class ListConnectionsRequest < Struct.new( :max_results, :next_token, :state, :environment_id, :provider, :attach_point) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ Types::Provider
Filter the results to only include Connection objects to the given Provider.
713 714 715 716 717 718 719 720 721 722 |
# File 'lib/aws-sdk-interconnect/types.rb', line 713 class ListConnectionsRequest < Struct.new( :max_results, :next_token, :state, :environment_id, :provider, :attach_point) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Filter the results to only include Connection objects in the given Connection$state.
713 714 715 716 717 718 719 720 721 722 |
# File 'lib/aws-sdk-interconnect/types.rb', line 713 class ListConnectionsRequest < Struct.new( :max_results, :next_token, :state, :environment_id, :provider, :attach_point) SENSITIVE = [] include Aws::Structure end |