Class: Aws::Interconnect::Types::Provider
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::Provider
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Provider is a union - when making an API calls you must set exactly one of the members.
Provider is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Provider corresponding to the set member.
Describes the respective AWS Interconnect Partner organization.
Direct Known Subclasses
Defined Under Namespace
Classes: CloudServiceProvider, LastMileProvider, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_service_provider ⇒ String
The provider’s name.
-
#last_mile_provider ⇒ String
The provider’s name.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#cloud_service_provider ⇒ String
The provider’s name. Specifically, connections to/from this Cloud Service Provider will be considered Multicloud connections.
832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/aws-sdk-interconnect/types.rb', line 832 class Provider < Struct.new( :cloud_service_provider, :last_mile_provider, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CloudServiceProvider < Provider; end class LastMileProvider < Provider; end class Unknown < Provider; end end |
#last_mile_provider ⇒ String
The provider’s name. Specifically, connections to/from this Last Mile Provider will be considered LastMile connections.
832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/aws-sdk-interconnect/types.rb', line 832 class Provider < Struct.new( :cloud_service_provider, :last_mile_provider, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CloudServiceProvider < Provider; end class LastMileProvider < Provider; end class Unknown < Provider; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
832 833 834 |
# File 'lib/aws-sdk-interconnect/types.rb', line 832 def unknown @unknown end |