Class: Aws::Interconnect::Types::RemoteAccountIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::RemoteAccountIdentifier
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Note:
RemoteAccountIdentifier is a union - when making an API calls you must set exactly one of the members.
The types of identifiers that may be needed for remote account specification.
Direct Known Subclasses
Defined Under Namespace
Classes: Identifier, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
A generic bit of identifying information.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#identifier ⇒ String
A generic bit of identifying information. Can be used in place of any of the more specific types.
857 858 859 860 861 862 863 864 865 866 |
# File 'lib/aws-sdk-interconnect/types.rb', line 857 class RemoteAccountIdentifier < Struct.new( :identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Identifier < RemoteAccountIdentifier; end class Unknown < RemoteAccountIdentifier; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
857 858 859 |
# File 'lib/aws-sdk-interconnect/types.rb', line 857 def unknown @unknown end |