Class: Aws::Interconnect::Types::UpdateConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Interconnect::Types::UpdateConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-interconnect/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bandwidth ⇒ String
Request a new bandwidth size on the given Connection.
-
#client_token ⇒ String
Idempotency token used for the request.
-
#description ⇒ String
An updated description to apply to the Connection.
-
#identifier ⇒ String
The identifier of the Connection that should be updated.
Instance Attribute Details
#bandwidth ⇒ String
Request a new bandwidth size on the given Connection.
Note that changes to the size may be subject to additional policy, and does require the remote partner provider to acknowledge and permit this new bandwidth size.
976 977 978 979 980 981 982 983 |
# File 'lib/aws-sdk-interconnect/types.rb', line 976 class UpdateConnectionRequest < Struct.new( :identifier, :description, :bandwidth, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Idempotency token used for the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
976 977 978 979 980 981 982 983 |
# File 'lib/aws-sdk-interconnect/types.rb', line 976 class UpdateConnectionRequest < Struct.new( :identifier, :description, :bandwidth, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An updated description to apply to the Connection
976 977 978 979 980 981 982 983 |
# File 'lib/aws-sdk-interconnect/types.rb', line 976 class UpdateConnectionRequest < Struct.new( :identifier, :description, :bandwidth, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the Connection that should be updated.
976 977 978 979 980 981 982 983 |
# File 'lib/aws-sdk-interconnect/types.rb', line 976 class UpdateConnectionRequest < Struct.new( :identifier, :description, :bandwidth, :client_token) SENSITIVE = [] include Aws::Structure end |